@@ -19,7 +19,7 @@
 #' This function is intended to be used with the Darwin execution engine. The execution engine
 #' runs OHDSI studies in a pre-defined runtime environment and makes several environment
 #' variables available for connecting to a CDM database. Programmer writing code to run
-#' on the execution engine and simply use `cdm <- cdm_from_environment()` to create a cdm reference
+#' on the execution engine and simply use `cdm <- cdmFromEnvironment()` to create a cdm reference
 #' object to use for their analysis and the database connection and cdm object should be
 #' automatically created. This obviates the need for site specific code for connecting
 #' to the database and creating the cdm reference object.
@@ -40,7 +40,8 @@
 #'    \item{WRITE_SCHEMA: The shema where the user has write access and tables will be created during study execution.}
 #' }
 #'
-#' @param write_prefix (string) An optional prefix to use for all tables written to the CDM.
+#'
+#' @param write_prefix,writePrefix (string) An optional prefix to use for all tables written to the CDM.
 #'
 #' @return A cdm_reference object
 #' @export
@@ -51,14 +52,16 @@
 #' library(CDMConnector)
 #'
 #' # This will only work in an evironment where the proper variables are present.
-#' cdm <- cdm_from_environment()
+#' cdm <- cdmFromEnvironment()
 #'
 #' # Proceed with analysis using the cdm object.
 #'
 #' # Close the database connection when done.
-#' cdm_disconnect(cdm)
+#' cdmDisconnect(cdm)
 #' }
-cdm_from_environment <- function(write_prefix = "") {
+cdmFromEnvironment <- function(writePrefix = "") {
+
+  lifecycle::deprecate_soft("1.7.0", "cdmFromEnvironment()")
 
   vars <- c("DBMS_TYPE",
             "DATA_SOURCE_NAME",
@@ -86,7 +89,7 @@ cdm_from_environment <- function(write_prefix = "") {
 
     checkmate::assert_choice(db, CDMConnector::example_datasets())
     con <- DBI::dbConnect(duckdb::duckdb(), CDMConnector::eunomia_dir(db))
-    cdm <- CDMConnector::cdm_from_con(con, "main", "main", cdm_version = "5.3", cdm_name = db)
+    cdm <- CDMConnector::cdmFromCon(con, "main", "main", cdmVersion = "5.3", cdmName = db)
     return(cdm)
   }
 
@@ -165,9 +168,9 @@ cdm_from_environment <- function(write_prefix = "") {
     write_schema <- c(schema = Sys.getenv("WRITE_SCHEMA"))
   }
 
-  if (write_prefix != "") {
+  if (writePrefix != "") {
     if (Sys.getenv("DBMS_TYPE") != "snowflake") {
-      write_schema <- c(write_schema, prefix = write_prefix)
+      write_schema <- c(write_schema, prefix = writePrefix)
     }
   }
 
@@ -181,12 +184,12 @@ cdm_from_environment <- function(write_prefix = "") {
     cdm_schema <- Sys.getenv("CDM_SCHEMA")
   }
 
-  cdm <- CDMConnector::cdm_from_con(
+  cdm <- CDMConnector::cdmFromCon(
     con = con,
-    cdm_schema = cdm_schema,
-    write_schema = write_schema,
-    cdm_version = Sys.getenv("CDM_VERSION"),
-    cdm_name = Sys.getenv("DATA_SOURCE_NAME"))
+    cdmSchema = cdm_schema,
+    writeSchema = write_schema,
+    cdmVersion = Sys.getenv("CDM_VERSION"),
+    cdmName = Sys.getenv("DATA_SOURCE_NAME"))
 
   if (length(names(cdm)) == 0) {
     cli::cli_abort("CDM object creation failed!")
@@ -194,3 +197,12 @@ cdm_from_environment <- function(write_prefix = "") {
 
   return(cdm)
 }
+
+#' `r lifecycle::badge("deprecated")
+#' @rdname cdmFromEnvironment
+#' @export
+cdm_from_environment <- function(write_prefix = ""){
+  lifecycle::deprecate_soft("1.7.0", "cdm_from_environment()")
+
+  cdmFromEnvironment(writePrefix = write_prefix)
+}
