@@ -49,16 +49,16 @@
 #' df <- mtcars_tbl %>%
 #'  dplyr::group_by(cyl) %>%
 #'  dplyr::mutate(mean = mean(mpg, na.rm = TRUE)) %>%
-#'  summarise_quantile(mpg, probs = c(0, 0.2, 0.4, 0.6, 0.8, 1),
-#'                     name_suffix = "quant") %>%
+#'  summariseQuantile(mpg, probs = c(0, 0.2, 0.4, 0.6, 0.8, 1),
+#'                    nameSuffix = "quant") %>%
 #'  dplyr::collect()
 #'
 #' DBI::dbDisconnect(con, shutdown = TRUE)
 #' }
-summarise_quantile <- function(.data, x = NULL, probs, name_suffix = "value") {
+summariseQuantile <- function(.data, x = NULL, probs, nameSuffix = "value") {
   checkmate::assertClass(.data, "tbl_sql")
   checkmate::assert_double(probs, min.len = 1, lower = 0, upper = 1)
-  checkmate::assert_character(name_suffix, null.ok = TRUE)
+  checkmate::assert_character(nameSuffix, null.ok = TRUE)
 
   selection_context <- .data$lazy_query$select_operation
 
@@ -106,7 +106,7 @@ summarise_quantile <- function(.data, x = NULL, probs, name_suffix = "value") {
 
   probs = sort(unique(probs))
   quant_expr <- purrr::map(probs, ~ rlang::expr(min(ifelse(accumulated >= !!.x * total, !!x, NA), na.rm = TRUE)))
-  names(quant_expr) <- paste0('p', as.character(probs * 100), '_', name_suffix)
+  names(quant_expr) <- paste0('p', as.character(probs * 100), '_', nameSuffix)
 
   query <- rlang::expr(
     .data %>%
@@ -121,26 +121,31 @@ summarise_quantile <- function(.data, x = NULL, probs, name_suffix = "value") {
   eval(query)
 }
 
-
-#' @rdname summarise_quantile
+#' `r lifecycle::badge("deprecated")`
+#' @rdname summariseQuantile
 #' @export
-summarize_quantile <- summarise_quantile
-
-
-#' @rdname summarise_quantile
-#' @export
-summariseQuantile <- function(.data,
-                              x = NULL,
-                              probs,
-                              nameSuffix = "value") {
-  x <- rlang::enexpr(x)
-  summarise_quantile(.data = .data,
-                     x = !!x,
-                     probs = probs,
-                     name_suffix = nameSuffix)
+summarize_quantile <- function(.data, x = NULL, probs, name_suffix = "value") {
+  lifecycle::deprecate_soft("1.7.0", "summarize_quantile()", "summariseQuantile()")
+  summariseQuantile(.data, x = x, probs = probs, nameSuffix = name_suffix)
 }
 
 
-#' @rdname summarise_quantile
+#' @rdname summariseQuantile
+#' @export
+summarise_quantile <- function(.data,
+                              x = NULL,
+                              probs,
+                              name_suffix = "value") {
+  lifecycle::deprecate_soft("1.7.0", "summarise_quantile()", "summariseQuantile()")
+
+  x <- rlang::enexpr(x)
+  summariseQuantile(.data = .data,
+                     x = !!x,
+                     probs = probs,
+                     nameSuffix = name_suffix)
+}
+
+
+#' @rdname summariseQuantile
 #' @export
 summarizeQuantile <- summariseQuantile
