@@ -5,30 +5,30 @@ test_that("downloadEunomiaData", {
 
   path <- downloadEunomiaData("GiBleed", overwrite = T)
   con <- DBI::dbConnect(duckdb::duckdb(eunomiaDir("GiBleed")))
-  cdm <- cdm_from_con(con, "main", cdm_name = "test")
+  cdm <- cdmFromCon(con, "main", cdmName = "test")
   expect_s3_class(cdm, "cdm_reference")
   DBI::dbDisconnect(con, shutdown = TRUE)
 
   con <- DBI::dbConnect(duckdb::duckdb(eunomiaDir("synthea-anemia-10k")))
-  cdm <- cdm_from_con(con, "main")
+  cdm <- cdmFromCon(con, "main")
   expect_s3_class(cdm, "cdm_reference")
   DBI::dbDisconnect(con, shutdown = TRUE)
 
   path <- downloadEunomiaData("synthea-breast_cancer-10k", overwrite = T)
-  con <- DBI::dbConnect(duckdb::duckdb(eunomia_dir("synthea-breast_cancer-10k")))
-  cdm <- cdm_from_con(con, "main")
+  con <- DBI::dbConnect(duckdb::duckdb(eunomiaDir("synthea-breast_cancer-10k")))
+  cdm <- cdmFromCon(con, "main")
   expect_s3_class(cdm, "cdm_reference")
   DBI::dbDisconnect(con, shutdown = TRUE)
 
   path <- downloadEunomiaData("synthea-covid19-10k", overwrite = T)
-  con <- DBI::dbConnect(duckdb::duckdb(eunomia_dir("synthea-covid19-10k")))
-  cdm <- cdm_from_con(con, "main")
+  con <- DBI::dbConnect(duckdb::duckdb(eunomiaDir("synthea-covid19-10k")))
+  cdm <- cdmFromCon(con, "main")
   expect_s3_class(cdm, "cdm_reference")
   DBI::dbDisconnect(con, shutdown = TRUE)
 
   path <- downloadEunomiaData("synthea-covid19-200k", overwrite = T)
-  con <- DBI::dbConnect(duckdb::duckdb(eunomia_dir("synthea-covid19-200k")))
-  cdm <- cdm_from_con(con, "main")
+  con <- DBI::dbConnect(duckdb::duckdb(eunomiaDir("synthea-covid19-200k")))
+  cdm <- cdmFromCon(con, "main")
   expect_s3_class(cdm, "cdm_reference")
   DBI::dbDisconnect(con, shutdown = TRUE)
 
@@ -39,18 +39,20 @@ test_that("downloadEunomiaData", {
 test_that("empty cdm works", {
   # skip("manual test")
   skip_if_not_installed("duckdb")
-  skip_if_not(eunomia_is_available("empty_cdm"))
+  skip_if_not(eunomiaIsAvailable("empty_cdm"))
 
-  expect_true("empty_cdm" %in% example_datasets())
+  expect_true("empty_cdm" %in% exampleDatasets())
 
   expect_no_error({
-    con <- DBI::dbConnect(duckdb::duckdb(eunomia_dir("empty_cdm")))
-    cdm <- cdm_from_con(con, "main", "main", cdm_name = "empty_cdm")
+    con <- DBI::dbConnect(duckdb::duckdb(eunomiaDir("empty_cdm")))
+    cdm <- cdmFromCon(con, "main", "main", cdmName = "empty_cdm")
   })
 
-  rowcounts <- purrr::map_int(cdm_select_tbl(cdm, -tbl_group("vocab")),
+
+  rowcounts <- purrr::map_int(cdmSelect(cdm, -tblGroup("vocab")),
                               ~dplyr::pull(dplyr::count(.), 'n'))
 
+
   expect_true(all(rowcounts == 0))
   DBI::dbDisconnect(con, shutdown = T)
 })
@@ -60,14 +62,14 @@ test_that("synpuf-1k example data has achilles tables", {
   skip_on_ci() # datasets are large and take a while to download
   skip_if_not_installed("duckdb")
 
-  con <- DBI::dbConnect(duckdb::duckdb(), eunomia_dir("synpuf-1k", "5.3"))
-  cdm <- cdm_from_con(con, "main", "main", achilles_schema = "main")
+  con <- DBI::dbConnect(duckdb::duckdb(), eunomiaDir("synpuf-1k", "5.3"))
+  cdm <- cdmFromCon(con, "main", "main", achillesSchema = "main")
   expect_true(all(c("achilles_analysis", "achilles_results", "achilles_results_dist") %in% names(cdm)))
   cdmDisconnect(cdm)
   expect_true(eunomiaIsAvailable("synpuf-1k", "5.3"))
 
-  con <- DBI::dbConnect(duckdb::duckdb(), eunomia_dir("synpuf-1k", "5.4"))
-  cdm <- cdm_from_con(con, "main", "main", achilles_schema = "main")
+  con <- DBI::dbConnect(duckdb::duckdb(), eunomiaDir("synpuf-1k", "5.4"))
+  cdm <- cdmFromCon(con, "main", "main", achillesSchema = "main")
   expect_true(all(c("achilles_analysis", "achilles_results", "achilles_results_dist") %in% names(cdm)))
   cdmDisconnect(cdm)
   expect_true(eunomiaIsAvailable("synpuf-1k", "5.4"))
